@@ -34,8 +34,14 @@ val update : t -> var:string -> f:(string option -> string option) -> t
 
 val to_sexp : t -> Sexp.t
 
+val to_dyn : t -> Dyn.t
+
 val of_string_map : string String.Map.t -> t
 
 val iter : t -> f:(string -> string -> unit) -> unit
 
 val pp : Format.formatter -> t -> unit
+
+val cons_path : t -> dir:Path.t -> t
+
+val path : t -> Path.t list
